# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # ORGANIZATION ADDRESS - superuser
    def v1_superuser_organization_organization_address_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_address_address_type_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-address-type-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION ADDRESS - administrator

    def v1_administrator_organization_organization_address_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_address_address_type_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-address-type-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION ADDRESS - manager

    def v1_manager_organization_organization_address_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_address_address_type_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-address-type-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION ADDRESS - assistant

    def v1_assistant_organization_organization_address_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_address_address_type_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationaddress-address-type-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TYPOLOGY - superuser

    def v1_superuser_organization_email_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_email_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TYPOLOGY - administrator

    def v1_administrator_organization_email_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_email_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TYPOLOGY - manager

    def v1_manager_organization_email_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_email_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TYPOLOGY - assistant

    def v1_assistant_organization_email_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_email_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:emailtypology-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # PHONE TYPOLOGY - superuser

    def v1_superuser_organization_phone_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_phone_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # PHONE TYPOLOGY - administrator

    def v1_administrator_organization_phone_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_phone_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # PHONE TYPOLOGY - manager

    def v1_manager_organization_phone_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_phone_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # PHONE TYPOLOGY - assistant

    def v1_assistant_organization_phone_typology_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_phone_typology_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:phonetypology-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION TYPE - superuser

    def v1_superuser_organization_organization_type_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_type_category_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-category-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION TYPE - administrator

    def v1_administrator_organization_organization_type_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_type_category_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-category-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION TYPE - manager

    def v1_manager_organization_organization_type_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_type_category_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-category-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION TYPE - assistant

    def v1_assistant_organization_organization_type_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_type_category_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationtype-category-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION FORM - superuser

    def v1_superuser_organization_organization_form_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_form_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION FORM - administrator

    def v1_administrator_organization_organization_form_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_form_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION FORM - manager

    def v1_manager_organization_organization_form_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_form_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION FORM - assistant

    def v1_assistant_organization_organization_form_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_form_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationform-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION - superuser

    def v1_superuser_organization_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION - administrator

    def v1_administrator_organization_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION - manager

    def v1_manager_organization_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION - assistant

    def v1_assistant_organization_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organization-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER ORGANIZATION - superuser

    def v1_superuser_organization_owner_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER ORGANIZATION - administrator

    def v1_administrator_organization_owner_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER ORGANIZATION - manager

    def v1_manager_organization_owner_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER ORGANIZATION - assistant

    def v1_assistant_organization_owner_organization_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_organization_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownerorganization-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION EMAIL - superuser

    def v1_superuser_organization_organization_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION EMAIL - administrator

    def v1_administrator_organization_organization_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION EMAIL - manager

    def v1_manager_organization_organization_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION EMAIL - assistant

    def v1_assistant_organization_organization_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationemail-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION PHONE - superuser

    def v1_superuser_organization_organization_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION PHONE - administrator

    def v1_administrator_organization_organization_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION PHONE - manager

    def v1_manager_organization_organization_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION PHONE - assistant

    def v1_assistant_organization_organization_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationphone-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION SOCIAL PAGE - superuser

    def v1_superuser_organization_organization_social_page_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_organization_social_page_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-social-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION SOCIAL PAGE - administrator

    def v1_administrator_organization_organization_social_page_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_organization_social_page_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-social-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION SOCIAL PAGE - manager

    def v1_manager_organization_organization_social_page_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_organization_social_page_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-social-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ORGANIZATION SOCIAL PAGE - assistant

    def v1_assistant_organization_organization_social_page_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_organization_social_page_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:organizationsocialpage-social-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT ROLE - superuser

    def v1_superuser_organization_contact_role_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_role_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT ROLE - administrator

    def v1_administrator_organization_contact_role_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_role_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT ROLE - manager

    def v1_manager_organization_contact_role_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_role_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT ROLE - assistant

    def v1_assistant_organization_contact_role_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_role_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactrole-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT TITLE - superuser

    def v1_superuser_organization_contact_title_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_title_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT TITLE - administrator

    def v1_administrator_organization_contact_title_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_title_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT TITLE - manager

    def v1_manager_organization_contact_title_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_title_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT TITLE - assistant

    def v1_assistant_organization_contact_title_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_title_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contacttitle-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT - superuser

    def v1_superuser_organization_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT - administrator

    def v1_administrator_organization_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT - manager

    def v1_manager_organization_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT - assistant

    def v1_assistant_organization_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contact-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER CONTACT - superuser

    def v1_superuser_organization_owner_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_owner_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER CONTACT - administrator

    def v1_administrator_organization_owner_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_owner_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER CONTACT - manager

    def v1_manager_organization_owner_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_owner_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # OWNER CONTACT - assistant

    def v1_assistant_organization_owner_contact_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_owner_contact_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:ownercontact-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT EMAIL - superuser

    def v1_superuser_organization_contact_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT EMAIL - administrator

    def v1_administrator_organization_contact_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT EMAIL - manager

    def v1_manager_organization_contact_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT EMAIL - assistant

    def v1_assistant_organization_contact_email_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_email_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactemail-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT PHONE - superuser

    def v1_superuser_organization_contact_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT PHONE - administrator

    def v1_administrator_organization_contact_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT PHONE - manager

    def v1_manager_organization_contact_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT PHONE - assistant

    def v1_assistant_organization_contact_phone_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_phone_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactphone-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT SOCIAL ACCOUNT - superuser

    def v1_superuser_organization_contact_social_account_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_organization_contact_social_account_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-social-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT SOCIAL ACCOUNT - administrator

    def v1_administrator_organization_contact_social_account_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_organization_contact_social_account_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-social-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT SOCIAL ACCOUNT - manager

    def v1_manager_organization_contact_social_account_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_organization_contact_social_account_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-social-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # CONTACT SOCIAL ACCOUNT - assistant

    def v1_assistant_organization_contact_social_account_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_organization_contact_social_account_social_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-organization:contactsocialaccount-social-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
